// Copyright 2011 Thomas Kamps anubis1@linux-ecke.de
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#ifndef BOOKMARKFOLDER_H
#define BOOKMARKFOLDER_H

#include <QList>
#include <QAction>
#include <QDomElement>

#include "bookmark.h"

class BookmarkFolder {
	public:
		BookmarkFolder();
		~BookmarkFolder();
		static BookmarkFolder* readFolder(QObject* parent, QDomElement folder, bool isRootFolder=false);

		BookmarkFolder* getFolder(QString name);
		QDomElement toXml(QDomDocument* doc);

		QAction* action() { return m_action; }
		QAction* gotoAction() { return m_gotoAction; }
		QAction* allAction() { return m_allAction; }
		QAction* emptyAction() { return m_emptyAction; }

		void addFolder(BookmarkFolder* folder, bool sort=false);
		void addBookmark(Bookmark* bookmark);
		void removeFolder(BookmarkFolder* folder);
		void removeBookmark(Bookmark* bookmark);
		void addSeparator();

		void setName(QString name);
		QString name() { return m_name; }

		QList<BookmarkFolder*> subfolders() { return m_subfolders; }
		QList<Bookmark*> bookmarks() { return m_bookmarks; }

		void addAllAction();

		int size();

		void updateVisibility();

	private:
		void addEmptyAction();
		void rearrangeEntries();

		QString m_name;
		QList<BookmarkFolder*> m_subfolders;
		QList<Bookmark*> m_bookmarks;

		QAction* m_action;
		QAction* m_gotoAction;
		QAction* m_allAction;
		QAction* m_emptyAction;
};

#endif // BOOKMARKFOLDER_H
